#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SAFE_MIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SAFE_MIN_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/safe_min.hpp>

#endif
